@@ -7,7 +7,6 @@ Revised on Thur Mar 18 16:04:00 2021
 
 New Version 1.2.3
 """
-
 import itertools
 import numpy as np
 import pandas as pd
@@ -15,11 +14,10 @@ from upsetplot import from_memberships
 from upsetplot import plot
 
 
-
-def FindERG( data, depth=2, sort_num=20):
+def FindERG(data, depth=2, sort_num=20, verbose=False):
     '''
     Find out endogenous reference gene
-    
+
     Parameters
     ----------
     data:pandas.DataFrmae
@@ -29,15 +27,18 @@ def FindERG( data, depth=2, sort_num=20):
         The larger the number, the fewer genes are screened out,Accuracy improvement
     sort_num:int
     	The size of the  peendogenous reference gener filter
-    	When the sample is large, it is recommended to increase the value	      
+    	When the sample is large, it is recommended to increase the value
+    verbose: bool
+        Make the function noisy, writing times and results.
     Returns
     -------
     result:list
         a list of endogenous reference gene
     '''
     lp=[]
-    import time,datetime
-    start = time.time()
+    if verbose:
+        import time,datetime
+        start = time.time()
     if depth==1:
         print('the depth must larger than 2')
         return
@@ -49,18 +50,16 @@ def FindERG( data, depth=2, sort_num=20):
         return
     count=0
     result=[]#result
+    bucket_size = 1000
     for i in itertools.combinations(data.columns[0:depth], 2):
         start = time.time()
         count=count+1
         test=data.replace(0,np.nan).dropna()
 
         last_std=pd.DataFrame()
-        length=len(data)//1000
-        remain=len(data)-1000*length
-        for k in range(1,length+1):  
-
-            test1=test[i[0]].iloc[1000*(k-1):1000*k]
-            test2=test[i[1]].iloc[1000*(k-1):1000*k]
+        for k in range(0 ,len(data), bucket_size):
+            test1=test[i[0]].iloc[k:k + bucket_size]
+            test2=test[i[1]].iloc[k:k + bucket_size]
             data_len=len(test1.values)
             table1=np.array(test1.values.tolist()*data_len).reshape(data_len,data_len)
             table2=pd.DataFrame(table1.T/table1)
@@ -73,31 +72,11 @@ def FindERG( data, depth=2, sort_num=20):
             table6=(table2-table5).std()
             table6.index=test1.index
             l_std=table6.sort_values()[0:sort_num]
-            if(k==1):
+            if(k==0):
                 last_std=l_std
             else:
                 last_std=pd.concat([last_std,l_std])
 
-        test1=test[i[0]].iloc[length*1000:length*1000+remain]
-        test2=test[i[1]].iloc[length*1000:length*1000+remain]
-        data_len=len(test1.values)
-        table1=np.array(test1.values.tolist()*data_len).reshape(data_len,data_len)
-        table2=pd.DataFrame(table1.T/table1)
-        table2.index=test1.index
-
-        table4=np.array(test2.values.tolist()*data_len).reshape(data_len,data_len)
-        table5=pd.DataFrame(table4.T/table4)
-        table5.index=test1.index
-
-        table6=(table2-table5).std()
-        table6.index=test1.index
-        l_std=table6.sort_values()[0:sort_num]
-
-        if(k==1):
-            last_std=l_std
-        else:
-            last_std=pd.concat([last_std,l_std])
-
         last_std=last_std.sort_values()[0:sort_num]
 
         testlist=list(last_std.index)
@@ -109,25 +88,26 @@ def FindERG( data, depth=2, sort_num=20):
         if(count>1):
             result=list(set(testlist).intersection(set(result))) #Venn
     example = from_memberships(lp,data=range(len(lp)))
-    end = time.time()
-    print("calculate time:%.2fs"%(end-start))
-    print(result)
+    if verbose:
+        end = time.time()
+        print("calculate time:%.2fs"%(end-start))
+        print(result)
     if depth>2:
-            plot(example)
+        plot(example)
     return result
 
 
 def normalizationdata( data, ERGname):
     '''
     Get a DataFrame disposed by standardization
-    
+
     Parameters
     ----------
     data:pandas.DataFrmae
         DataFrame of data points with each entry in the form:['gene_id','sample1',...]
     ERGname:str
         the gene use to normalization
-          
+
     Returns
     -------
     result:pandas.DataFrame
@@ -137,10 +117,3 @@ def normalizationdata( data, ERGname):
     da=data.iloc[:,0:len(data.columns)]/np.asarray(l.iloc[0,0:len(data.columns)])
     da=da*l.iloc[0,0]
     return da
-
-            
-        
-        
-        
-        
-
